@@ -2,15 +2,15 @@ from __future__ import print_function, division
 
 from sympy.ntheory import isprime
 from sympy.combinatorics.permutations import Permutation, _af_invert, _af_rmul
-from sympy.core.compatibility import xrange
+from sympy.core.compatibility import range
 
 rmul = Permutation.rmul
 _af_new = Permutation._af_new
 
 ############################################
-###
-### Utilities for computational group theory
-###
+#
+# Utilities for computational group theory
+#
 ############################################
 
 
@@ -29,6 +29,7 @@ def _base_ordering(base, degree):
 
     A list ``base_ordering`` such that ``base_ordering[point]`` is the
     number of ``point`` in the ordering.
+
     Examples
     ========
 
@@ -59,10 +60,10 @@ def _base_ordering(base, degree):
     """
     base_len = len(base)
     ordering = [0]*degree
-    for i in xrange(base_len):
+    for i in range(base_len):
         ordering[base[i]] = i
     current = base_len
-    for i in xrange(degree):
+    for i in range(degree):
         if i not in base:
             ordering[i] = current
             current += 1
@@ -81,10 +82,10 @@ def _check_cycles_alt_sym(perm):
 
     >>> from sympy.combinatorics.util import _check_cycles_alt_sym
     >>> from sympy.combinatorics.permutations import Permutation
-    >>> a = Permutation([[0,1,2,3,4,5,6,7,8,9,10], [11, 12]])
+    >>> a = Permutation([[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10], [11, 12]])
     >>> _check_cycles_alt_sym(a)
     False
-    >>> b = Permutation([[0,1,2,3,4,5,6], [7,8,9,10]])
+    >>> b = Permutation([[0, 1, 2, 3, 4, 5, 6], [7, 8, 9, 10]])
     >>> _check_cycles_alt_sym(b)
     True
 
@@ -99,7 +100,7 @@ def _check_cycles_alt_sym(perm):
     current_len = 0
     total_len = 0
     used = set()
-    for i in xrange(n//2):
+    for i in range(n//2):
         if not i in used and i < n//2 - total_len:
             current_len = 1
             used.add(i)
@@ -115,7 +116,7 @@ def _check_cycles_alt_sym(perm):
 
 
 def _distribute_gens_by_base(base, gens):
-    """
+    r"""
     Distribute the group elements ``gens`` by membership in basic stabilizers.
 
     Notice that for a base `(b_1, b_2, ..., b_k)`, the basic stabilizers
@@ -148,12 +149,12 @@ def _distribute_gens_by_base(base, gens):
     >>> D = DihedralGroup(3)
     >>> D.schreier_sims()
     >>> D.strong_gens
-    [Permutation(0, 1, 2), Permutation(0, 2), Permutation(1, 2)]
+    [(0 1 2), (0 2), (1 2)]
     >>> D.base
     [0, 1]
     >>> _distribute_gens_by_base(D.base, D.strong_gens)
-    [[Permutation(0, 1, 2), Permutation(0, 2), Permutation(1, 2)],
-     [Permutation(1, 2)]]
+    [[(0 1 2), (0 2), (1 2)],
+     [(1 2)]]
 
     See Also
     ========
@@ -164,7 +165,7 @@ def _distribute_gens_by_base(base, gens):
     """
     base_len = len(base)
     degree = gens[0].size
-    stabs = [[] for _ in xrange(base_len)]
+    stabs = [[] for _ in range(base_len)]
     max_stab_index = 0
     for gen in gens:
         j = 0
@@ -172,12 +173,13 @@ def _distribute_gens_by_base(base, gens):
             j += 1
         if j > max_stab_index:
             max_stab_index = j
-        for k in xrange(j + 1):
+        for k in range(j + 1):
             stabs[k].append(gen)
     for i in range(max_stab_index + 1, base_len):
         stabs[i].append(_af_new(list(range(degree))))
     return stabs
 
+
 def _handle_precomputed_bsgs(base, strong_gens, transversals=None,
                              basic_orbits=None, strong_gens_distr=None):
     """
@@ -216,12 +218,7 @@ def _handle_precomputed_bsgs(base, strong_gens, transversals=None,
     >>> D.schreier_sims()
     >>> _handle_precomputed_bsgs(D.base, D.strong_gens,
     ... basic_orbits=D.basic_orbits)
-    ([{0: Permutation(2), 1: Permutation(0, 1, 2), 2: Permutation(0, 2)},
-    {1: Permutation(2), 2: Permutation(1, 2)}],
-    [[0, 1, 2], [1, 2]], [[Permutation(0, 1, 2),
-                           Permutation(0, 2),
-                           Permutation(1, 2)],
-                          [Permutation(1, 2)]])
+    ([{0: (2), 1: (0 1 2), 2: (0 2)}, {1: (2), 2: (1 2)}], [[0, 1, 2], [1, 2]], [[(0 1 2), (0 2), (1 2)], [(1 2)]])
 
     See Also
     ========
@@ -249,7 +246,7 @@ def _handle_precomputed_bsgs(base, strong_gens, transversals=None,
 
 
 def _orbits_transversals_from_bsgs(base, strong_gens_distr,
-                                   transversals_only=False):
+                                   transversals_only=False, slp=False):
     """
     Compute basic orbits and transversals from a base and strong generating set.
 
@@ -265,6 +262,10 @@ def _orbits_transversals_from_bsgs(base, strong_gens_distr,
     stabilizers
     ``transversals_only`` - a flag switching between returning only the
     transversals/ both orbits and transversals
+    ``slp`` - if ``True``, return a list of dictionaries containing the
+              generator presentations of the elements of the transversals,
+              i.e. the list of indices of generators from `strong_gens_distr[i]`
+              such that their product is the relevant transversal element
 
     Examples
     ========
@@ -279,9 +280,7 @@ def _orbits_transversals_from_bsgs(base, strong_gens_distr,
     >>> S.schreier_sims()
     >>> strong_gens_distr = _distribute_gens_by_base(S.base, S.strong_gens)
     >>> _orbits_transversals_from_bsgs(S.base, strong_gens_distr)
-    ([[0, 1, 2], [1, 2]],
-    [{0: Permutation(2), 1: Permutation(0, 1, 2), 2: Permutation(0, 2, 1)},
-    {1: Permutation(2), 2: Permutation(1, 2)}])
+    ([[0, 1, 2], [1, 2]], [{0: (2), 1: (0 1 2), 2: (0 2 1)}, {1: (2), 2: (1 2)}])
 
     See Also
     ========
@@ -293,17 +292,21 @@ def _orbits_transversals_from_bsgs(base, strong_gens_distr,
     base_len = len(base)
     degree = strong_gens_distr[0][0].size
     transversals = [None]*base_len
+    slps = [None]*base_len
     if transversals_only is False:
         basic_orbits = [None]*base_len
-    for i in xrange(base_len):
-        transversals[i] = dict(_orbit_transversal(degree, strong_gens_distr[i],
-                                 base[i], pairs=True))
+    for i in range(base_len):
+        transversals[i], slps[i] = _orbit_transversal(degree, strong_gens_distr[i],
+                                 base[i], pairs=True, slp=True)
+        transversals[i] = dict(transversals[i])
         if transversals_only is False:
             basic_orbits[i] = list(transversals[i].keys())
     if transversals_only:
         return transversals
     else:
-        return basic_orbits, transversals
+        if not slp:
+            return basic_orbits, transversals
+        return basic_orbits, transversals, slps
 
 
 def _remove_gens(base, strong_gens, basic_orbits=None, strong_gens_distr=None):
@@ -352,7 +355,7 @@ def _remove_gens(base, strong_gens, basic_orbits=None, strong_gens_distr=None):
     "Handbook of computational group theory"
 
     """
-    from sympy.combinatorics.perm_groups import PermutationGroup, _orbit
+    from sympy.combinatorics.perm_groups import _orbit
     base_len = len(base)
     degree = strong_gens[0].size
     if strong_gens_distr is None:
@@ -379,6 +382,7 @@ def _remove_gens(base, strong_gens, basic_orbits=None, strong_gens_distr=None):
                     res.remove(gen)
     return res
 
+
 def _strip(g, base, orbits, transversals):
     """
     Attempt to decompose a permutation using a (possibly partial) BSGS
@@ -420,7 +424,7 @@ def _strip(g, base, orbits, transversals):
     >>> S.schreier_sims()
     >>> g = Permutation([0, 2, 3, 1, 4])
     >>> _strip(g, S.base, S.basic_orbits, S.basic_transversals)
-    (Permutation(4), 5)
+    ((4), 5)
 
     Notes
     =====
@@ -456,7 +460,8 @@ def _strip(g, base, orbits, transversals):
         h = _af_rmul(_af_invert(u), h)
     return _af_new(h), base_len + 1
 
-def _strip_af(h, base, orbits, transversals, j):
+
+def _strip_af(h, base, orbits, transversals, j, slp=[], slps={}):
     """
     optimized _strip, with h, transversals and result in array form
     if the stripped elements is the identity, it returns False, base_len + 1
@@ -469,12 +474,24 @@ def _strip_af(h, base, orbits, transversals, j):
         if beta == base[i]:
             continue
         if beta not in orbits[i]:
-            return h, i + 1
+            if not slp:
+                return h, i + 1
+            return h, i + 1, slp
         u = transversals[i][beta]
         if h == u:
-            return False, base_len + 1
+            if not slp:
+                return False, base_len + 1
+            return False, base_len + 1, slp
         h = _af_rmul(_af_invert(u), h)
-    return h, base_len + 1
+        if slp:
+            u_slp = slps[i][beta][:]
+            u_slp.reverse()
+            u_slp = [(i, (g,)) for g in u_slp]
+            slp = u_slp + slp
+    if not slp:
+        return h, base_len + 1
+    return h, base_len + 1, slp
+
 
 def _strong_gens_from_distr(strong_gens_distr):
     """
@@ -500,10 +517,10 @@ def _strong_gens_from_distr(strong_gens_distr):
     >>> S = SymmetricGroup(3)
     >>> S.schreier_sims()
     >>> S.strong_gens
-    [Permutation(0, 1, 2), Permutation(2)(0, 1), Permutation(1, 2)]
+    [(0 1 2), (2)(0 1), (1 2)]
     >>> strong_gens_distr = _distribute_gens_by_base(S.base, S.strong_gens)
     >>> _strong_gens_from_distr(strong_gens_distr)
-    [Permutation(0, 1, 2), Permutation(2)(0, 1), Permutation(1, 2)]
+    [(0 1 2), (2)(0 1), (1 2)]
 
     See Also
     ========
