@@ -132,8 +132,8 @@ def prde_special_denom(a, ba, bd, G, DE, case='auto'):
                 etaa, etad = frac_in(dcoeff, DE.t)
                 A = parametric_log_deriv(alphaa, alphad, etaa, etad, DE)
                 if A is not None:
-                    a, m, z = A
-                    if a == 1:
+                    Q, m, z = A
+                    if Q == 1:
                         n = min(n, m)
 
         elif case == 'tan':
@@ -147,9 +147,9 @@ def prde_special_denom(a, ba, bd, G, DE, case='auto'):
                     A = parametric_log_deriv(alphaa, alphad, etaa, etad, DE)
                     B = parametric_log_deriv(betaa, betad, etaa, etad, DE)
                     if A is not None and B is not None:
-                        a, s, z = A
+                        Q, s, z = A
                         # TODO: Add test
-                        if a == 1:
+                        if Q == 1:
                             n = min(n, s/2)
 
     N = max(0, -nb)
@@ -858,8 +858,7 @@ def parametric_log_deriv_heu(fa, fd, wa, wd, DE, c1=None):
             # deg(q) > B, no solution for c.
             return None
 
-        N, M = s[c1].as_numer_denom()  # N and M are integers
-        N, M = Poly(N, DE.t), Poly(M, DE.t)
+        M, N = s[c1].as_numer_denom()
 
         nfmwa = N*fa*wd - M*wa*fd
         nfmwd = fd*wd
@@ -869,9 +868,7 @@ def parametric_log_deriv_heu(fa, fd, wa, wd, DE, c1=None):
             # (N*f - M*w) is not the logarithmic derivative of a k(t)-radical.
             return None
 
-        Q, e, v = Qv
-        if e != 1:
-            return None
+        Q, v = Qv
 
         if Q.is_zero or v.is_zero:
             return None
@@ -930,7 +927,7 @@ def parametric_log_deriv(fa, fd, wa, wd, DE):
 
 
 def is_deriv_k(fa, fd, DE):
-    """
+    r"""
     Checks if Df/f is the derivative of an element of k(t).
 
     a in k(t) is the derivative of an element of k(t) if there exists b in k(t)
@@ -980,9 +977,14 @@ def is_deriv_k(fa, fd, DE):
     of the logarithmic terms in L_args.
 
     To handle the case where we are given Df/f, not f, use is_deriv_k_in_field().
+
+    See also
+    ========
+    is_log_deriv_k_t_radical_in_field, is_log_deriv_k_t_radical
+
     """
     # Compute Df/f
-    dfa, dfd = fd*(fd*derivation(fa, DE) - fa*derivation(fd, DE)), fd**2*fa
+    dfa, dfd = (fd*derivation(fa, DE) - fa*derivation(fd, DE)), fd*fa
     dfa, dfd = dfa.cancel(dfd, include=True)
 
     # Our assumption here is that each monomial is recursively transcendental
@@ -1039,7 +1041,7 @@ def is_deriv_k(fa, fd, DE):
 
 
 def is_log_deriv_k_t_radical(fa, fd, DE, Df=True):
-    """
+    r"""
     Checks if Df is the logarithmic derivative of a k(t)-radical.
 
     b in k(t) can be written as the logarithmic derivative of a k(t) radical if
@@ -1089,6 +1091,11 @@ def is_log_deriv_k_t_radical(fa, fd, DE, Df=True):
 
     To handle the case where we are given Df, not f, use
     is_log_deriv_k_t_radical_in_field().
+
+    See also
+    ========
+    is_log_deriv_k_t_radical_in_field, is_deriv_k
+
     """
     H = []
     if Df:
@@ -1151,6 +1158,11 @@ def is_log_deriv_k_t_radical_in_field(fa, fd, DE, case='auto', z=None):
     """
     Checks if f can be written as the logarithmic derivative of a k(t)-radical.
 
+    It differs from is_log_deriv_k_t_radical(fa, fd, DE, Df=False)
+    for any given fa, fd, DE in that it finds the solution in the
+    given field not in some (possibly unspecified extension) and
+    "in_field" with the function name is used to indicate that.
+
     f in k(t) can be written as the logarithmic derivative of a k(t) radical if
     there exist n in ZZ and u in k(t) with n, u != 0 such that n*f == Du/u.
     Either returns (n, u) or None, which means that f cannot be written as the
@@ -1159,6 +1171,11 @@ def is_log_deriv_k_t_radical_in_field(fa, fd, DE, case='auto', z=None):
     case is one of {'primitive', 'exp', 'tan', 'auto'} for the primitive,
     hyperexponential, and hypertangent cases, respectively.  If case is 'auto',
     it will attempt to determine the type of the derivation automatically.
+
+    See also
+    ========
+    is_log_deriv_k_t_radical, is_deriv_k
+
     """
     fa, fd = fa.cancel(fd, include=True)
 
