@@ -11,11 +11,9 @@ from collections import defaultdict
 from sympy import (Add, Basic, cacheit, Dummy, Expr, Function, I,
                    KroneckerDelta, Mul, Pow, S, sqrt, Symbol, sympify, Tuple,
                    zeros)
-from sympy.core.compatibility import reduce, xrange
 from sympy.printing.str import StrPrinter
 
-from sympy.physics.quantum.qexpr import split_commutative_parts
-from sympy.core.compatibility import reduce
+from sympy.core.compatibility import range
 from sympy.utilities.iterables import has_dups
 from sympy.utilities import default_sort_key
 
@@ -207,20 +205,21 @@ class AntiSymmetricTensor(TensorSymbol):
         FIXME: This is a bottle-neck, can we do it faster?
         """
         h = hash(index)
+        label = str(index)
         if isinstance(index, Dummy):
             if index.assumptions0.get('above_fermi'):
-                return (20, h)
+                return (20, label, h)
             elif index.assumptions0.get('below_fermi'):
-                return (21, h)
+                return (21, label, h)
             else:
-                return (22, h)
+                return (22, label, h)
 
         if index.assumptions0.get('above_fermi'):
-            return (10, h)
+            return (10, label, h)
         elif index.assumptions0.get('below_fermi'):
-            return (11, h)
+            return (11, label, h)
         else:
-            return (12, h)
+            return (12, label, h)
 
     def _latex(self, printer):
         return "%s^{%s}_{%s}" % (
@@ -437,6 +436,9 @@ class AnnihilateBoson(BosonicOperator, Annihilator):
     def __repr__(self):
         return "AnnihilateBoson(%s)" % self.state
 
+    def _latex(self, printer):
+        return "b_{%s}" % self.state.name
+
 
 class CreateBoson(BosonicOperator, Creator):
     """
@@ -473,6 +475,9 @@ class CreateBoson(BosonicOperator, Creator):
     def __repr__(self):
         return "CreateBoson(%s)" % self.state
 
+    def _latex(self, printer):
+        return "b^\\dagger_{%s}" % self.state.name
+
 B = AnnihilateBoson
 Bd = CreateBoson
 
@@ -1034,6 +1039,7 @@ class FermionState(FockState):
         FockStateFermionKet((a,))
 
         A creator acting on vacuum below fermi vanishes
+
         >>> FKet([]).up(i)
         0
 
@@ -1076,10 +1082,12 @@ class FermionState(FockState):
         >>> p = Symbol('p')
 
         An annihilator acting on vacuum above fermi vanishes
+
         >>> FKet([]).down(a)
         0
 
         Also below fermi, it vanishes, unless we specify a fermi level > 0
+
         >>> FKet([]).down(i)
         0
         >>> FKet([],4).down(i)
@@ -1581,57 +1589,6 @@ class FixedBosonicBasis(BosonicBasis):
         return repr(self.basis)
 
 
-# def move(e, i, d):
-#     """
-#     Takes the expression "e" and moves the operator at the position i by "d".
-#     """
-#     if e.is_Mul:
-#         if d == 1:
-#             # e = a*b*c*d
-#             a = Mul(*e.args[:i])
-#             b = e.args[i]
-#             c = e.args[i+1]
-#             d = Mul(*e.args[i+2:])
-#             if isinstance(b, Dagger) and not isinstance(c, Dagger):
-#                 i, j = b.args[0].args[0], c.args[0]
-#                 return a*c*b*d-a*KroneckerDelta(i, j)*d
-#             elif not isinstance(b, Dagger) and isinstance(c, Dagger):
-#                 i, j = b.args[0], c.args[0].args[0]
-#                 return a*c*b*d-a*KroneckerDelta(i, j)*d
-#             else:
-#                 return a*c*b*d
-#         elif d == -1:
-#             # e = a*b*c*d
-#             a = Mul(*e.args[:i-1])
-#             b = e.args[i-1]
-#             c = e.args[i]
-#             d = Mul(*e.args[i+1:])
-#             if isinstance(b, Dagger) and not isinstance(c, Dagger):
-#                 i, j = b.args[0].args[0], c.args[0]
-#                 return a*c*b*d-a*KroneckerDelta(i, j)*d
-#             elif not isinstance(b, Dagger) and isinstance(c, Dagger):
-#                 i, j = b.args[0], c.args[0].args[0]
-#                 return a*c*b*d-a*KroneckerDelta(i, j)*d
-#             else:
-#                 return a*c*b*d
-#         else:
-#             if d > 1:
-#                 while d >= 1:
-#                     e = move(e, i, 1)
-#                     d -= 1
-#                     i += 1
-#                 return e
-#             elif d < -1:
-#                 while d <= -1:
-#                     e = move(e, i, -1)
-#                     d += 1
-#                     i -= 1
-#                 return e
-#     elif isinstance(e, Add):
-#         a, b = e.as_two_terms()
-#         return move(a, i, d) + move(b, i, d)
-#     raise NotImplementedError()
-
 class Commutator(Function):
     """
     The Commutator:  [A, B] = A*B - B*A
@@ -2038,7 +1995,7 @@ class NO(Expr):
 
         """
         ops = self.args[0].args
-        iter = xrange(len(ops) - 1, -1, -1)
+        iter = range(len(ops) - 1, -1, -1)
         for i in iter:
             if ops[i].is_q_annihilator:
                 yield i
@@ -2068,7 +2025,7 @@ class NO(Expr):
         """
 
         ops = self.args[0].args
-        iter = xrange(0, len(ops))
+        iter = range(0, len(ops))
         for i in iter:
             if ops[i].is_q_creator:
                 yield i
@@ -2104,7 +2061,6 @@ class NO(Expr):
         return ":%s:" % self.args[0]
 
 
-# @cacheit
 def contraction(a, b):
     """
     Calculates contraction of Fermionic operators a and b.
@@ -2309,7 +2265,7 @@ def evaluate_deltas(e):
         return e.func(*[evaluate_deltas(arg) for arg in e.args])
 
     elif isinstance(e, Mul):
-        # find all occurences of delta function and count each index present in
+        # find all occurrences of delta function and count each index present in
         # expression.
         deltas = []
         indices = {}
@@ -2325,11 +2281,12 @@ def evaluate_deltas(e):
         for d in deltas:
             # If we do something, and there are more deltas, we should recurse
             # to treat the resulting expression properly
-            if indices[d.killable_index]:
+            if d.killable_index.is_Symbol and indices[d.killable_index]:
                 e = e.subs(d.killable_index, d.preferred_index)
                 if len(deltas) > 1:
                     return evaluate_deltas(e)
-            elif indices[d.preferred_index] and d.indices_contain_equal_information:
+            elif (d.preferred_index.is_Symbol and indices[d.preferred_index]
+                  and d.indices_contain_equal_information):
                 e = e.subs(d.preferred_index, d.killable_index)
                 if len(deltas) > 1:
                     return evaluate_deltas(e)
@@ -2378,7 +2335,7 @@ def substitute_dummies(expr, new_indices=False, pretty_indices={}):
     Controlling output:
 
     By default the dummy symbols that are already present in the expression
-    will be reused in a different permuation.  However, if new_indices=True,
+    will be reused in a different permutation.  However, if new_indices=True,
     new dummies will be generated and inserted.  The keyword 'pretty_indices'
     can be used to control this generation of new symbols.
 
@@ -2584,7 +2541,7 @@ def _get_ordered_dummies(mul, verbose=False):
     args = Mul.make_args(mul)
     fac_dum = dict([ (fac, fac.atoms(Dummy)) for fac in args] )
     fac_repr = dict([ (fac, __kprint(fac)) for fac in args] )
-    all_dums = reduce(set.union, list(fac_dum.values()), set())
+    all_dums = set().union(*fac_dum.values())
     mask = {}
     for d in all_dums:
         if d.assumptions0.get('below_fermi'):
@@ -2593,12 +2550,11 @@ def _get_ordered_dummies(mul, verbose=False):
             mask[d] = '1'
         else:
             mask[d] = '2'
-    dum_repr = dict([ (d, __kprint(d)) for d in all_dums ])
+    dum_repr = {d: __kprint(d) for d in all_dums}
 
     def _key(d):
         dumstruct = [ fac for fac in fac_dum if d in fac_dum[fac] ]
-        other_dums = reduce(
-            set.union, [ fac_dum[fac] for fac in dumstruct ], set())
+        other_dums = set().union(*[fac_dum[fac] for fac in dumstruct])
         fac = dumstruct[-1]
         if other_dums is fac_dum[fac]:
             other_dums = fac_dum[fac].copy()
@@ -2690,8 +2646,8 @@ def _determine_ambiguous(term, ordered, ambiguous_groups):
         # handle this needs to be implemented.  In order to return something
         # useful nevertheless, we choose arbitrarily the first dummy and
         # determine the rest from this one.  This method is dependent on the
-        # actual dummy labels which violates an assumption for the canonization
-        # procedure.  A better implementation is needed.
+        # actual dummy labels which violates an assumption for the
+        # canonicalization procedure.  A better implementation is needed.
         group = [ d for d in ordered if d in ambiguous_groups[0] ]
         d = group[0]
         all_ordered.add(d)
@@ -2772,8 +2728,6 @@ def _get_contractions(string1, keep_only_fully_contracted=False):
             c = contraction(string1[i], string1[j])
 
             if c:
-                # print "found contraction",c
-
                 sign = (j - i + 1) % 2
                 if sign:
                     coeff = S.NegativeOne*c
@@ -2811,7 +2765,6 @@ def _get_contractions(string1, keep_only_fully_contracted=False):
     return Add(*result)
 
 
-# @cacheit
 def wicks(e, **kw_args):
     """
     Returns the normal ordered equivalent of an expression using Wicks Theorem.
@@ -2883,7 +2836,7 @@ def wicks(e, **kw_args):
     # For Mul-objects we can actually do something
     if isinstance(e, Mul):
 
-        # we dont want to mess around with commuting part of Mul
+        # we don't want to mess around with commuting part of Mul
         # so we factorize it out before starting recursion
         c_part = []
         string1 = []
