@@ -1,14 +1,14 @@
 from __future__ import print_function, division
 
 from .rv import (probability, expectation, density, where, given, pspace, cdf,
-        sample, sample_iter, random_symbols, independent, dependent,
-        sampling_density)
+        characteristic_function, sample, sample_iter, random_symbols, independent, dependent,
+        sampling_density, moment_generating_function)
 from sympy import sqrt
 
-__all__ = ['P', 'E', 'density', 'where', 'given', 'sample', 'cdf', 'pspace',
+__all__ = ['P', 'E', 'density', 'where', 'given', 'sample', 'cdf', 'characteristic_function', 'pspace',
         'sample_iter', 'variance', 'std', 'skewness', 'covariance',
         'dependent', 'independent', 'random_symbols', 'correlation',
-        'moment', 'cmoment', 'sampling_density']
+        'moment', 'cmoment', 'sampling_density', 'moment_generating_function']
 
 
 
